@@ -1,7 +1,7 @@
 package Bencher::Scenario::HashSlicing::slice;
 
 our $DATE = '2020-04-19'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -115,7 +115,7 @@ Bencher::Scenario::HashSlicing::slice - Benchmark hash slicing
 
 =head1 VERSION
 
-This document describes version 0.004 of Bencher::Scenario::HashSlicing::slice (from Perl distribution Bencher-Scenarios-HashSlicing), released on 2020-04-19.
+This document describes version 0.005 of Bencher::Scenario::HashSlicing::slice (from Perl distribution Bencher-Scenarios-HashSlicing), released on 2020-04-19.
 
 =head1 SYNOPSIS
 
@@ -234,11 +234,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::MoreUtils::slice_exists |    363000 |    2.75   |                 0.00% |               415.70% | 6.8e-10 |      30 |
- | Hash::Subset::hashref_subset  |    554740 |    1.8027 |                52.80% |               237.50% | 4.9e-12 |      20 |
- | map+grep                      |    566000 |    1.77   |                55.89% |               230.80% | 8.3e-10 |      20 |
- | map                           |    596190 |    1.6773 |                64.22% |               214.03% | 4.6e-12 |      20 |
- | Hash::Util::Pick::pick        |   1900000 |    0.53   |               415.70% |                 0.00% | 8.3e-10 |      20 |
+ | Hash::MoreUtils::slice_exists |    360000 |    2.78   |                 0.00% |               425.30% | 6.4e-10 |      34 |
+ | Hash::Subset::hashref_subset  |    564700 |    1.771  |                56.92% |               234.76% | 2.6e-11 |      21 |
+ | map+grep                      |    571000 |    1.75   |                58.74% |               230.92% | 8.4e-10 |      20 |
+ | map                           |    596010 |    1.6778 |                65.62% |               217.17% | 5.8e-12 |      20 |
+ | Hash::Util::Pick::pick        |   1900000 |    0.53   |               425.30% |                 0.00% | 8.3e-10 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table2#
@@ -246,11 +246,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::Subset::hashref_subset  |   1100000 |     920   |                 0.00% |               299.50% | 1.3e-09 |      35 |
- | Hash::MoreUtils::slice_exists |   1160000 |     862   |                 7.12% |               272.93% | 4.2e-10 |      20 |
- | map+grep                      |   1900000 |     520   |                78.41% |               123.92% | 8.3e-10 |      20 |
- | map                           |   2162000 |     462.5 |                99.59% |               100.16% | 5.2e-12 |      20 |
- | Hash::Util::Pick::pick        |   4300000 |     230   |               299.50% |                 0.00% | 4.2e-10 |      20 |
+ | Hash::Subset::hashref_subset  |   1100000 |       930 |                 0.00% |               301.52% | 1.5e-09 |      25 |
+ | Hash::MoreUtils::slice_exists |   1100000 |       880 |                 5.45% |               280.77% | 1.7e-09 |      20 |
+ | map+grep                      |   1930000 |       517 |                79.17% |               124.10% | 2.5e-10 |      20 |
+ | map                           |   2150000 |       465 |                99.34% |               101.43% | 1.9e-10 |      24 |
+ | Hash::Util::Pick::pick        |   4300000 |       230 |               301.52% |                 0.00% | 4.3e-10 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table3#
@@ -258,11 +258,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::MoreUtils::slice_exists |    364000 |    2.75   |                 0.00% |               410.84% | 7.5e-10 |      25 |
- | Hash::Subset::hashref_subset  |    550080 |    1.8179 |                51.28% |               237.69% | 4.5e-12 |      20 |
- | map+grep                      |    560000 |    1.8    |                54.13% |               231.43% | 2.5e-09 |      20 |
- | map                           |    588000 |    1.7    |                61.68% |               215.95% | 7.3e-10 |      26 |
- | Hash::Util::Pick::pick        |   1900000 |    0.54   |               410.84% |                 0.00% | 8.3e-10 |      20 |
+ | Hash::MoreUtils::slice_exists |    363000 |    2.75   |                 0.00% |               394.10% | 8.3e-10 |      20 |
+ | Hash::Subset::hashref_subset  |    560000 |    1.8    |                54.58% |               219.64% | 2.2e-09 |      27 |
+ | map+grep                      |    568000 |    1.76   |                56.29% |               216.15% | 8.9e-10 |      20 |
+ | map                           |    600790 |    1.6645 |                65.43% |               198.68% | 5.8e-12 |      22 |
+ | Hash::Util::Pick::pick        |   1800000 |    0.56   |               394.10% |                 0.00% | 3.5e-09 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table4#
@@ -270,11 +270,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::MoreUtils::slice_exists |   41500   |   24.1    |                 0.00% |               330.30% |   2e-08 |      20 |
- | map+grep                      |   61500   |   16.3    |                48.03% |               190.70% | 5.8e-09 |      26 |
- | map                           |   64894.4 |   15.4097 |                56.22% |               175.44% | 4.9e-12 |      20 |
- | Hash::Subset::hashref_subset  |   81800   |   12.2    |                96.82% |               118.62% | 2.8e-09 |      28 |
- | Hash::Util::Pick::pick        |  180000   |    5.6    |               330.30% |                 0.00% | 6.7e-09 |      20 |
+ | Hash::MoreUtils::slice_exists |   35748.8 |    27.973 |                 0.00% |               421.53% | 1.7e-11 |      20 |
+ | map+grep                      |   62674   |    15.956 |                75.32% |               197.48% | 1.4e-10 |      20 |
+ | map                           |   64500   |    15.5   |                80.53% |               188.89% | 5.5e-09 |      29 |
+ | Hash::Subset::hashref_subset  |   84400   |    11.9   |               136.02% |               120.97% | 3.2e-09 |      22 |
+ | Hash::Util::Pick::pick        |  190000   |     5.4   |               421.53% |                 0.00% | 6.5e-09 |      21 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table5#
@@ -282,11 +282,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::Subset::hashref_subset  |   1069900 |    934.68 |                 0.00% |               301.67% |   5e-12 |      20 |
- | Hash::MoreUtils::slice_exists |   1160000 |    861    |                 8.51% |               270.18% | 4.2e-10 |      20 |
- | map+grep                      |   1930000 |    518    |                80.57% |               122.44% | 1.8e-10 |      28 |
- | map                           |   2182000 |    458.2  |               103.98% |                96.91% | 2.3e-11 |      20 |
- | Hash::Util::Pick::pick        |   4300000 |    233    |               301.67% |                 0.00% | 9.3e-11 |      25 |
+ | Hash::Subset::hashref_subset  |   1080000 |     926   |                 0.00% |               309.68% | 3.5e-10 |      29 |
+ | Hash::MoreUtils::slice_exists |   1156000 |     865.2 |                 7.08% |               282.58% | 1.7e-11 |      20 |
+ | map+grep                      |   1920000 |     520   |                78.30% |               129.78% |   2e-10 |      23 |
+ | map                           |   2120000 |     471   |                96.78% |               108.19% |   2e-10 |      21 |
+ | Hash::Util::Pick::pick        |   4400000 |     230   |               309.68% |                 0.00% | 2.8e-10 |      22 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table6#
@@ -294,11 +294,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::MoreUtils::slice_exists |    362000 |    2.76   |                 0.00% |               419.95% | 6.9e-10 |      29 |
- | Hash::Subset::hashref_subset  |    559710 |    1.7867 |                54.65% |               236.21% |   5e-12 |      20 |
- | map+grep                      |    560000 |    1.8    |                55.24% |               234.93% | 2.1e-09 |      29 |
- | map                           |    590610 |    1.6932 |                63.19% |               218.62% | 5.7e-12 |      20 |
- | Hash::Util::Pick::pick        |   1900000 |    0.53   |               419.95% |                 0.00% | 6.2e-10 |      20 |
+ | Hash::MoreUtils::slice_exists |    354730 |    2.8191 |                 0.00% |               405.16% | 5.7e-12 |      20 |
+ | Hash::Subset::hashref_subset  |    554700 |    1.803  |                56.37% |               223.06% | 2.3e-11 |      20 |
+ | map+grep                      |    566000 |    1.77   |                59.54% |               216.63% | 1.2e-09 |      20 |
+ | map                           |    601900 |    1.661  |                69.69% |               197.69% | 2.3e-11 |      20 |
+ | Hash::Util::Pick::pick        |   1800000 |    0.56   |               405.16% |                 0.00% |   1e-09 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table7#
@@ -306,11 +306,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::MoreUtils::slice_exists |     35000 |    28     |                 0.00% |               383.15% | 5.3e-08 |      20 |
- | map+grep                      |     60000 |    16.7   |                69.26% |               185.45% | 5.5e-09 |      29 |
- | map                           |     61600 |    16.2   |                73.66% |               178.22% | 6.7e-09 |      20 |
- | Hash::Subset::hashref_subset  |     80068 |    12.489 |               125.74% |               114.03% | 8.8e-11 |      29 |
- | Hash::Util::Pick::pick        |    170000 |     5.8   |               383.15% |                 0.00% | 8.3e-09 |      20 |
+ | Hash::MoreUtils::slice_exists |   35567.4 |   28.1157 |                 0.00% |               402.20% | 5.8e-12 |      28 |
+ | map+grep                      |   61000   |   16      |                70.40% |               194.72% | 2.4e-08 |      24 |
+ | map                           |   63400   |   15.8    |                78.26% |               181.72% | 6.7e-09 |      20 |
+ | Hash::Subset::hashref_subset  |   81694   |   12.241  |               129.69% |               118.65% | 1.7e-11 |      22 |
+ | Hash::Util::Pick::pick        |  180000   |    5.6    |               402.20% |                 0.00% | 8.3e-09 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table8#
@@ -318,11 +318,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::MoreUtils::slice_exists |      3820 |       262 |                 0.00% |               240.25% | 2.1e-07 |      21 |
- | map+grep                      |      5570 |       179 |                45.85% |               133.29% | 5.3e-08 |      20 |
- | map                           |      5730 |       175 |                49.92% |               126.96% | 5.1e-08 |      22 |
- | Hash::Subset::hashref_subset  |      7770 |       129 |               103.23% |                67.42% | 5.3e-08 |      20 |
- | Hash::Util::Pick::pick        |     13000 |        77 |               240.25% |                 0.00% |   1e-07 |      22 |
+ | Hash::MoreUtils::slice_exists |      3460 |       289 |                 0.00% |               276.88% |   2e-07 |      22 |
+ | map+grep                      |      5400 |       180 |                57.24% |               139.68% | 2.1e-07 |      20 |
+ | map                           |      5600 |       180 |                63.20% |               130.93% | 6.2e-07 |      21 |
+ | Hash::Subset::hashref_subset  |      7700 |       130 |               122.44% |                69.43% | 2.7e-07 |      20 |
+ | Hash::Util::Pick::pick        |     13000 |        77 |               276.88% |                 0.00% | 2.1e-07 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table9#
@@ -330,11 +330,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::Subset::hashref_subset  |   1080000 |    930    |                 0.00% |               302.11% | 4.2e-10 |      20 |
- | Hash::MoreUtils::slice_exists |   1200000 |    860    |                 7.69% |               273.41% | 1.2e-09 |      20 |
- | map+grep                      |   1948000 |    513.34 |                81.13% |               122.00% | 4.5e-12 |      20 |
- | map                           |   2162000 |    462.5  |               101.06% |                99.99% | 5.7e-12 |      20 |
- | Hash::Util::Pick::pick        |   4325000 |    231.2  |               302.11% |                 0.00% | 5.7e-12 |      23 |
+ | Hash::Subset::hashref_subset  |   1060000 |     940   |                 0.00% |               293.79% | 4.2e-10 |      20 |
+ | Hash::MoreUtils::slice_exists |   1156000 |     865.4 |                 8.65% |               262.45% | 1.7e-11 |      20 |
+ | map+grep                      |   1920000 |     522   |                80.17% |               118.56% | 2.1e-10 |      20 |
+ | map                           |   2100000 |     470   |               100.76% |                96.15% | 6.2e-10 |      21 |
+ | Hash::Util::Pick::pick        |   4200000 |     240   |               293.79% |                 0.00% | 4.2e-10 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table10#
@@ -342,11 +342,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::MoreUtils::slice_exists |    356000 |    2.81   |                 0.00% |               417.42% | 7.2e-10 |      27 |
- | map+grep                      |    550190 |    1.8176 |                54.53% |               234.84% | 4.8e-12 |      20 |
- | Hash::Subset::hashref_subset  |    550190 |    1.8176 |                54.53% |               234.83% | 4.8e-12 |      20 |
- | map                           |    573520 |    1.7436 |                61.08% |               221.21% |   5e-12 |      20 |
- | Hash::Util::Pick::pick        |   1800000 |    0.54   |               417.42% |                 0.00% | 8.3e-10 |      20 |
+ | Hash::MoreUtils::slice_exists |    350000 |    2.8    |                 0.00% |               405.48% |   3e-09 |      25 |
+ | Hash::Subset::hashref_subset  |    550130 |    1.8178 |                56.51% |               222.98% | 1.7e-11 |      20 |
+ | map+grep                      |    556600 |    1.797  |                58.34% |               219.23% | 1.2e-10 |      20 |
+ | map                           |    590500 |    1.693  |                68.00% |               200.88% | 2.3e-11 |      20 |
+ | Hash::Util::Pick::pick        |   1800000 |    0.56   |               405.48% |                 0.00% | 8.3e-10 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table11#
@@ -354,11 +354,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::MoreUtils::slice_exists |     40200 |      24.9 |                 0.00% |               313.52% | 6.7e-09 |      20 |
- | map+grep                      |     57000 |      18   |                41.74% |               191.74% | 3.3e-08 |      20 |
- | map                           |     61100 |      16.4 |                51.87% |               172.28% | 6.4e-09 |      22 |
- | Hash::Subset::hashref_subset  |     76000 |      13   |                89.49% |               118.23% | 2.5e-08 |      22 |
- | Hash::Util::Pick::pick        |    170000 |       6   |               313.52% |                 0.00% | 6.7e-09 |      20 |
+ | Hash::MoreUtils::slice_exists |   38700   |   25.9    |                 0.00% |               323.82% | 1.3e-08 |      21 |
+ | map+grep                      |   56807.7 |   17.6033 |                46.94% |               188.42% | 5.8e-12 |      20 |
+ | map                           |   61300   |   16.3    |                58.54% |               167.33% | 6.7e-09 |      20 |
+ | Hash::Subset::hashref_subset  |   77921.6 |   12.8334 |               101.56% |               110.27% | 5.8e-12 |      20 |
+ | Hash::Util::Pick::pick        |  160000   |    6.1    |               323.82% |                 0.00% | 1.3e-08 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table12#
@@ -366,11 +366,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::Subset::hashref_subset  |   1068100 |    936.27 |                 0.00% |               303.37% | 4.9e-12 |      20 |
- | Hash::MoreUtils::slice_exists |   1140000 |    875    |                 6.95% |               277.16% | 3.1e-10 |      37 |
- | map+grep                      |   1917000 |    521.6  |                79.50% |               124.71% | 5.2e-12 |      26 |
- | map                           |   2140000 |    467.28 |               100.37% |               101.32% | 4.5e-12 |      20 |
- | Hash::Util::Pick::pick        |   4308000 |    232.1  |               303.37% |                 0.00% | 5.2e-12 |      20 |
+ | Hash::Subset::hashref_subset  |   1070000 |     935   |                 0.00% |               303.97% | 3.6e-10 |      27 |
+ | Hash::MoreUtils::slice_exists |   1150000 |     872   |                 7.32% |               276.42% | 4.2e-10 |      20 |
+ | map+grep                      |   1849000 |     540.8 |                72.97% |               133.55% | 5.7e-12 |      32 |
+ | map                           |   2100000 |     470   |               100.64% |               101.35% | 8.3e-10 |      20 |
+ | Hash::Util::Pick::pick        |   4300000 |     230   |               303.97% |                 0.00% | 4.4e-10 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table13#
@@ -378,11 +378,11 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::Subset::hashref_subset  |   1076500 |    928.92 |                 0.00% |               304.62% | 5.7e-12 |      22 |
- | Hash::MoreUtils::slice_exists |   1156300 |    864.86 |                 7.41% |               276.71% | 5.2e-12 |      20 |
- | map+grep                      |   1936500 |    516.41 |                79.88% |               124.94% | 4.5e-12 |      20 |
- | map                           |   2200000 |    460    |               101.74% |               100.56% | 8.3e-10 |      20 |
- | Hash::Util::Pick::pick        |   4356000 |    229.6  |               304.62% |                 0.00% | 4.3e-12 |      22 |
+ | Hash::Subset::hashref_subset  |   1070000 |     932   |                 0.00% |               291.04% | 3.9e-10 |      23 |
+ | Hash::MoreUtils::slice_exists |   1147000 |     871.5 |                 6.90% |               265.81% | 2.3e-11 |      23 |
+ | map+grep                      |   1904000 |     525.3 |                77.35% |               120.49% | 5.7e-12 |      20 |
+ | map                           |   2100000 |     470   |                99.68% |                95.84% | 8.3e-10 |      20 |
+ | Hash::Util::Pick::pick        |   4200000 |     240   |               291.04% |                 0.00% | 8.3e-10 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table14#
@@ -390,25 +390,25 @@ Benchmark with default options (C<< bencher -m HashSlicing::slice >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Hash::Subset::hashref_subset  |   1100000 |       920 |                 0.00% |               297.46% | 1.7e-09 |      20 |
- | Hash::MoreUtils::slice_exists |   1170000 |       858 |                 6.93% |               271.70% | 3.3e-10 |      32 |
- | map+grep                      |   1890000 |       530 |                73.22% |               129.45% | 2.1e-10 |      20 |
- | map                           |   2100000 |       480 |                92.34% |               106.64% | 5.8e-10 |      23 |
- | Hash::Util::Pick::pick        |   4300000 |       230 |               297.46% |                 0.00% | 5.2e-10 |      20 |
+ | Hash::Subset::hashref_subset  |   1100000 |     900   |                 0.00% |               289.43% | 1.2e-09 |      20 |
+ | Hash::MoreUtils::slice_exists |   1160000 |     864   |                 4.48% |               272.74% | 4.2e-10 |      21 |
+ | map+grep                      |   1904000 |     525.3 |                71.80% |               126.68% | 5.7e-12 |      20 |
+ | map                           |   2130000 |     470   |                91.96% |               102.87% | 2.1e-10 |      20 |
+ | Hash::Util::Pick::pick        |   4300000 |     230   |               289.43% |                 0.00% | 5.2e-10 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m HashSlicing::slice --module-startup >>):
 
  #table15#
- +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | participant         | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
- +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | Hash::MoreUtils     |        10 |                 0 |                 0.00% |                35.95% |   0.00041 |      21 |
- | Hash::Subset        |        10 |                 0 |                10.65% |                22.86% |   0.00027 |      20 |
- | Hash::Util::Pick    |        12 |                 2 |                26.66% |                 7.33% | 5.9e-05   |      20 |
- | perl -e1 (baseline) |        10 |                 0 |                35.95% |                 0.00% |   0.00026 |      20 |
- +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ | participant         | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ | Hash::MoreUtils     |        10 |                 0 |                 0.00% |                29.02% | 0.00031 |      21 |
+ | Hash::Util::Pick    |        10 |                 0 |                 7.65% |                19.85% | 0.00028 |      20 |
+ | Hash::Subset        |        10 |                 0 |                10.15% |                17.13% | 0.00018 |      20 |
+ | perl -e1 (baseline) |        10 |                 0 |                29.02% |                 0.00% | 0.00026 |      20 |
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
